"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _styled = _interopRequireDefault(require("@emotion/styled"));

var _utils = require("@solui/utils");

var _2 = require("./");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; if (obj != null) { var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const Container = _styled.default.div``;
const StyledProgress = (0, _styled.default)(_2.Progress)`
  margin: 1rem;
`;
const StyledError = (0, _styled.default)(_2.ErrorBox)`
  margin: 1rem;
`;

var _default = ({
  network,
  spec,
  artifacts,
  className,
  processSpec,
  validateGroupInputs,
  validatePanel,
  executePanel
}) => {
  const [buildResult, setBuildResult] = (0, _react.useState)();
  const onValidateGroupInputs = (0, _react.useCallback)(async ({
    groupId,
    inputs
  }) => {
    return validateGroupInputs({
      artifacts,
      spec,
      groupId,
      inputs,
      web3: _utils._.get(network, 'web3')
    });
  }, [spec, artifacts, network, validateGroupInputs]);
  const onValidatePanel = (0, _react.useCallback)(async ({
    groupId,
    panelId,
    inputs
  }) => {
    return validatePanel({
      artifacts,
      spec,
      groupId,
      panelId,
      inputs,
      web3: _utils._.get(network, 'web3')
    });
  }, [spec, artifacts, network, validatePanel]);
  const onExecutePanel = (0, _react.useCallback)(async ({
    groupId,
    panelId,
    inputs
  }) => {
    if (!network) {
      throw new Error('Network not available');
    }

    return executePanel({
      artifacts,
      spec,
      groupId,
      panelId,
      inputs,
      web3: network.web3
    });
  }, [spec, artifacts, network, executePanel]);
  (0, _react.useEffect)(() => {
    (async () => {
      const int = new _2.InterfaceBuilder();

      try {
        const {
          errors
        } = await processSpec({
          spec,
          artifacts
        }, int);

        if (errors.notEmpty) {
          throw (0, _utils.createErrorWithDetails)('There were processing errors', errors.toStringArray());
        }

        setBuildResult({
          interface: int
        });
      } catch (err) {
        console.error(err);
        setBuildResult({
          error: err
        });
      }
    })();
  }, [onValidatePanel, onValidateGroupInputs, onExecutePanel, spec, artifacts, processSpec]);
  return _react.default.createElement(Container, {
    className: className
  }, !network ? _react.default.createElement(StyledProgress, null, "Waiting for Ethereum network connection") : _react.default.createElement("div", null, _react.default.createElement(_2.NetworkInfo, {
    network: network
  }), !buildResult ? _react.default.createElement(StyledProgress, null, "Rendering...") : _react.default.createElement("div", null, buildResult.error ? _react.default.createElement(StyledError, {
    error: buildResult.error
  }) : buildResult.interface.buildContent({
    onValidateGroupInputs,
    onValidatePanel,
    onExecutePanel
  }))));
};

exports.default = _default;