"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _styled = _interopRequireDefault(require("@emotion/styled"));

var _styles = require("@solui/styles");

var _utils = require("@solui/utils");

var _ErrorBox = _interopRequireDefault(require("./ErrorBox"));

var _IconButton = _interopRequireDefault(require("./IconButton"));

var _TextInput = _interopRequireDefault(require("./TextInput"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; if (obj != null) { var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const Container = _styled.default.div`
  ${(0, _styles.flex)({
  justify: 'flex-start',
  align: 'flex-start'
})};
`;
const Label = _styled.default.label`
  ${({
  theme
}) => theme.font('body', 'regular')};
  display: block;
  color: ${({
  theme
}) => theme.inputLabelTextColor};
  font-size: 1.1rem;
  margin-bottom: 0.3rem;
`;
const StyledErrorBox = (0, _styled.default)(_ErrorBox.default)`
  width: 100%;
  margin-top: 0.5rem;
  font-size: 1rem;
`;
const FieldTooltip = (0, _styled.default)(_IconButton.default)`
  margin-left: 0.5rem;
`;
const HelpText = _styled.default.p`
  ${({
  theme
}) => theme.font('header', 'thin', 'italic')};
  font-size: 80%;
  display: block;
  color: ${({
  theme
}) => theme.inputHelpTextColor};
  margin-top: 0.2rem;
`;

var _default = ({
  className,
  name,
  title,
  value,
  onChange,
  type,
  validationConfig,
  validationStatus
}) => {
  const {
    helpText,
    tooltip
  } = (0, _react.useMemo)(() => {
    const tips = [];
    let helpStr;

    switch (type) {
      case 'address':
        {
          const allowedTypes = _utils._.get(validationConfig, 'allowedTypes', []);

          if (Array.isArray(allowedTypes) && allowedTypes.length) {
            tips.push(`Allowed types: ${allowedTypes.join(', ')}`);
          }

          helpStr = `Length: ${value ? value.length : 0}`;
          break;
        }

      case 'string':
        {
          const minLen = parseInt(_utils._.get(validationConfig, 'length.min'), 10);
          const maxLen = parseInt(_utils._.get(validationConfig, 'length.max'), 10);

          if (!Number.isNaN(minLen) && !Number.isNaN(maxLen)) {
            tips.push(`Length: must be between ${minLen} and ${maxLen} characters.`);
          }

          helpStr = `Length: ${value ? value.length : 0}`;
          break;
        }

      case 'int':
      case 'uint':
        {
          const minVal = _utils._.get(validationConfig, 'range.min');

          const maxVal = _utils._.get(validationConfig, 'range.max');

          if (minVal && maxVal) {
            tips.push(`Value: must be between ${minVal} and ${maxVal}.`);
          }

          const unit = _utils._.get(validationConfig, 'unit');

          if (unit) {
            tips.push(`Unit: ${unit.toUpperCase()}`);
            const realVal = (0, _utils.toEthVal)(value, unit);
            helpStr = `Real value: ${realVal ? realVal.toWei().toString(10) : '(not set)'}`;
          }

          break;
        }

      default:
    }

    return {
      helpText: helpStr,
      tooltip: tips.length ? tips.join('\n') : null
    };
  }, [type, value, validationConfig]);
  return _react.default.createElement(Container, {
    className: className
  }, _react.default.createElement(Label, null, title, tooltip ? _react.default.createElement(FieldTooltip, {
    tooltip: tooltip,
    icon: {
      name: 'info'
    }
  }) : null), _react.default.createElement(_TextInput.default, _extends({
    name: name,
    onChange: onChange,
    value: value,
    type: "text"
  }, validationStatus)), helpText ? _react.default.createElement(HelpText, null, helpText) : null, validationStatus.error ? _react.default.createElement(StyledErrorBox, {
    error: validationStatus.error
  }) : null);
};

exports.default = _default;