"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GroupBuilder = exports.Group = void 0;

var _react = _interopRequireWildcard(require("react"));

var _styled = _interopRequireDefault(require("@emotion/styled"));

var _styles = require("@solui/styles");

var _Panel = require("./Panel");

var _PanelInputs = _interopRequireDefault(require("./PanelInputs"));

var _Image = _interopRequireDefault(require("./Image"));

var _hooks = require("./hooks");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; if (obj != null) { var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const containerActiveCss = theme => `
  background-color: ${theme.groupActiveBgColor};
  border: 1px solid ${theme.groupActiveBorderColor};
  ${(0, _styles.boxShadow)({
  color: theme.groupActiveShadowColor
})};
`;

const Container = _styled.default.div`
  ${(0, _styles.smoothTransitions)()};
  background-color: ${({
  theme
}) => theme.groupBgColor};
  border: 1px solid ${({
  theme
}) => theme.groupBorderColor};
  ${({
  expanded,
  theme
}) => expanded ? containerActiveCss(theme) : ''};
  border-radius: 5px;
  cursor: ${({
  expanded
}) => expanded ? 'default' : 'pointer'};
  padding: 1rem;

  &:hover {
    ${({
  theme
}) => containerActiveCss(theme)};
  }
`;
const Info = _styled.default.div`
  ${(0, _styles.flex)({
  direction: 'row',
  justify: 'flex-start'
})}
`;
const InfoText = _styled.default.div`
  ${(0, _styles.flex)({
  align: 'flex-start'
})}
`;
const Title = _styled.default.h2`
  font-size: 1.5rem;
  margin: 0;
`;
const Description = _styled.default.p`
  font-size: 1.2rem;
  margin: 0.6rem 0 0;
  line-height: 1.2em;
`;
const GroupImage = (0, _styled.default)(_Image.default)`
  width: 100px;
  min-width: 100px;
  height: auto;
  max-height: 100px;
  margin-right: 1rem;
`;
const Content = _styled.default.section`
  ${(0, _styles.smoothTransitions)()};
  max-height: ${({
  expanded
}) => expanded ? 'auto' : '0'};
  margin-top: ${({
  expanded
}) => expanded ? '2rem' : '0'};
  overflow: hidden;
`;
const PanelContainer = _styled.default.div`
  border: 1px dashed ${({
  theme
}) => theme.panelBorderColor};
  background-color: ${({
  theme
}) => theme.panelBgColor};
  border-radius: 5px;
  margin-top: 3rem;

  &:hover {
    border-color:
  }
`;

const Group = ({
  expanded,
  onClick,
  onValidateGroupInputs,
  onExecutePanel,
  onValidatePanel,
  id,
  title,
  description,
  image,
  inputs,
  panels
}) => {
  const onClickContainer = (0, _react.useCallback)(() => onClick(id), [onClick, id]);
  const {
    inputValue,
    inputValidation,
    allInputsAreValid,
    onInputChange
  } = (0, _hooks.useInput)({
    inputs,
    validate: (0, _react.useCallback)(groupInputs => {
      return onValidateGroupInputs({
        groupId: id,
        inputs: groupInputs
      });
    }, [id, onValidateGroupInputs])
  });
  const onExecute = (0, _react.useCallback)(async (panelId, panelInputs) => {
    if (!allInputsAreValid) {
      console.error('Please fix inputs');
      return null;
    }

    const combinedInputs = _objectSpread({}, inputValue, {}, panelInputs);

    return onExecutePanel({
      groupId: id,
      panelId,
      inputs: combinedInputs
    });
  }, [id, inputValue, allInputsAreValid, onExecutePanel]);
  const onValidate = (0, _react.useCallback)(async (panelId, panelInputs) => {
    const combinedInputs = _objectSpread({}, inputValue, {}, panelInputs);

    return onValidatePanel({
      groupId: id,
      panelId,
      inputs: combinedInputs
    });
  }, [id, inputValue, onValidatePanel]);
  return _react.default.createElement(Container, {
    onClick: onClickContainer,
    expanded: expanded
  }, _react.default.createElement(Info, null, image ? _react.default.createElement(GroupImage, image) : null, _react.default.createElement(InfoText, null, _react.default.createElement(Title, null, title), description ? _react.default.createElement(Description, null, description) : null)), _react.default.createElement(Content, {
    expanded: expanded
  }, inputs.length ? _react.default.createElement(_PanelInputs.default, {
    inputs: inputs,
    inputValue: inputValue,
    inputValidation: inputValidation,
    onInputChange: onInputChange
  }) : null, panels.map(panel => _react.default.createElement(PanelContainer, {
    key: panel.id
  }, panel.buildContent({
    canExecute: allInputsAreValid,
    onExecute,
    onValidate
  })))));
};

exports.Group = Group;

class GroupBuilder {
  constructor({
    id: _id,
    attrs: {
      title,
      description,
      image
    }
  }) {
    _defineProperty(this, "getInput", async (id, name, config) => {
      if (this.currentPanel) {
        await this.currentPanel.addInput(id, name, config);
      } else {
        this.inputs.push({
          id,
          name,
          config
        });
      }
    });

    _defineProperty(this, "startPanel", (id, config) => {
      this.currentPanel = new _Panel.PanelBuilder({
        id,
        config
      });
    });

    _defineProperty(this, "endPanel", () => {
      this.panels.push(this.currentPanel);
      this.currentPanel = null;
    });

    this.attrs = {
      id: _id,
      title,
      description,
      image
    };
    this.inputs = [];
    this.panels = [];
    this.currentPanel = null;
  }

  get id() {
    return this.attrs.id;
  }

  buildContent(props) {
    return _react.default.createElement(Group, _extends({
      inputs: this.inputs,
      panels: this.panels
    }, this.attrs, props));
  }

}

exports.GroupBuilder = GroupBuilder;