"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.InterfaceBuilder = exports.Interface = void 0;

var _react = _interopRequireWildcard(require("react"));

var _styled = _interopRequireDefault(require("@emotion/styled"));

var _styles = require("@solui/styles");

var _Group = require("./Group");

var _Image = _interopRequireDefault(require("./Image"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; if (obj != null) { var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const Container = _styled.default.div`
  ${(0, _styles.flex)()}
  margin: 2rem 1rem;
`;
const Info = _styled.default.div`
  ${(0, _styles.flex)()}
  text-align: center;
  margin: 0 auto 1rem;
  padding: 0 2rem;

  ${_styles.media.when({
  minW: 'mobile'
})} {
    max-width: 600px;
  }
`;
const MainImage = (0, _styled.default)(_Image.default)`
  width: 250px;
  height: auto;
  max-height: 250px;
  border-radius: 5px;
  margin-bottom: 1.5rem;
`;
const Title = _styled.default.h1`
  font-size: 2rem;
  margin: 0 0 1.5rem;
`;
const Description = _styled.default.p`
  font-size: 1.2rem;
  margin: 0;
  line-height: 1.2em;
`;
const Groups = _styled.default.div`
  width: 100%;
  ${_styles.media.when({
  minW: 'mobile'
})} {
    max-width: 700px;
  }
`;
const GroupContainer = _styled.default.li`
  display: block;
  margin: 3rem 0 1rem;
`;

const Interface = ({
  onValidateGroupInputs,
  onExecutePanel,
  onValidatePanel,
  title,
  description,
  image,
  groups
}) => {
  const [selectedGroup, setSelectedGroup] = (0, _react.useState)();
  return _react.default.createElement(Container, null, _react.default.createElement(Info, null, image ? _react.default.createElement(MainImage, image) : null, _react.default.createElement(Title, null, title), _react.default.createElement(Description, null, description)), _react.default.createElement(Groups, null, groups.map(group => _react.default.createElement(GroupContainer, {
    key: group.id
  }, group.buildContent({
    onValidateGroupInputs,
    onValidatePanel,
    onExecutePanel,
    onClick: setSelectedGroup,
    expanded: selectedGroup === group.id
  })))));
};

exports.Interface = Interface;

class InterfaceBuilder {
  constructor() {
    _defineProperty(this, "startUi", (id, attrs) => {
      this.attrs = attrs;
    });

    _defineProperty(this, "endUi", () => {});

    _defineProperty(this, "startGroup", async (id, attrs) => {
      this.currentGroup = new _Group.GroupBuilder({
        id,
        attrs
      });
    });

    _defineProperty(this, "endGroup", async () => {
      this.groups.push(this.currentGroup);
      this.currentGroup = null;
    });

    _defineProperty(this, "getInput", async (...args) => {
      if (!this.currentGroup) {
        throw new Error('Not in a group');
      }

      return this.currentGroup.getInput(...args);
    });

    _defineProperty(this, "startPanel", async (...args) => {
      if (!this.currentGroup) {
        throw new Error('Not in a group');
      }

      await this.currentGroup.startPanel(...args);
    });

    _defineProperty(this, "endPanel", async (...args) => {
      if (!this.currentGroup) {
        throw new Error('Not in a group');
      }

      await this.currentGroup.endPanel(...args);
    });

    this.groups = [];
    this.currentGroup = null;
  }

  buildContent(props) {
    return _react.default.createElement(Interface, _extends({
      groups: this.groups
    }, this.attrs, props));
  }

}

exports.InterfaceBuilder = InterfaceBuilder;