"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PanelBuilder = exports.Panel = void 0;

var _react = _interopRequireWildcard(require("react"));

var _styled = _interopRequireDefault(require("@emotion/styled"));

var _hooks = require("./hooks");

var _PanelInputs = _interopRequireDefault(require("./PanelInputs"));

var _Result = _interopRequireDefault(require("./Result"));

var _Icon = _interopRequireDefault(require("./Icon"));

var _Button = _interopRequireDefault(require("./Button"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; if (obj != null) { var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const Container = _styled.default.div`
  padding: 1rem;
`;
const Title = _styled.default.h3`
  ${({
  theme
}) => theme.font('body', 'bold')};
  font-size: 1.1rem;
  margin: 0 0 2rem;
`;
const StyledButton = (0, _styled.default)(_Button.default)`
  margin-top: 1rem;
`;
const StyledResult = (0, _styled.default)(_Result.default)`
  margin-top: 1rem;
  max-width: 100%;
`;

const Panel = ({
  className,
  onExecute,
  onValidate,
  canExecute,
  id: panelId,
  config,
  inputs
}) => {
  const [execResult, setExecResult] = (0, _react.useState)();
  const [isExecuting, setIsExecuting] = (0, _react.useState)(false);
  const {
    inputValue,
    inputValidation,
    allInputsAreValid,
    onInputChange
  } = (0, _hooks.useInput)({
    inputs,
    validate: (0, _react.useCallback)(panelInputs => onValidate(panelId, panelInputs), [panelId, onValidate])
  });
  const onExecutePanel = (0, _react.useCallback)(async () => {
    if (!allInputsAreValid) {
      console.error('Please fix inputs');
      return;
    }

    setExecResult(null);
    setIsExecuting(true);

    try {
      const value = await onExecute(panelId, inputValue);
      setExecResult({
        value
      });
    } catch (error) {
      setExecResult({
        error
      });
    } finally {
      setIsExecuting(false);
    }
  }, [allInputsAreValid, onExecute, panelId, inputValue]);
  return _react.default.createElement(Container, {
    className: className
  }, _react.default.createElement(Title, null, config.title), inputs.length ? _react.default.createElement(_PanelInputs.default, {
    inputs: inputs,
    inputValue: inputValue,
    inputValidation: inputValidation,
    onInputChange: onInputChange
  }) : null, _react.default.createElement(StyledButton, {
    onClick: onExecutePanel,
    disabled: isExecuting || !canExecute || !allInputsAreValid
  }, isExecuting ? _react.default.createElement(_Icon.default, {
    name: "laugh-squint",
    spin: true
  }) : 'Execute'), execResult ? _react.default.createElement(StyledResult, {
    result: execResult
  }) : null);
};

exports.Panel = Panel;

class PanelBuilder {
  constructor({
    id,
    config
  }) {
    this.attrs = {
      id,
      config,
      inputs: []
    };
  }

  get id() {
    return this.attrs.id;
  }

  addInput(id, name, config) {
    this.attrs.inputs.push({
      id,
      name,
      config
    });
  }

  buildContent(props) {
    return _react.default.createElement(Panel, _extends({}, this.attrs, props));
  }

}

exports.PanelBuilder = PanelBuilder;