"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.DEFAULT_RENDER_LOADING = exports.DEFAULT_RENDER_ERROR = exports.DEFAULT_IS_LOADING = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactApollo = require("react-apollo");

var _graphql = require("@solui/graphql");

var _ErrorBox = _interopRequireDefault(require("./ErrorBox"));

var _LoadingIcon = _interopRequireDefault(require("./LoadingIcon"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

const DEFAULT_IS_LOADING = ({
  loading
}) => loading;

exports.DEFAULT_IS_LOADING = DEFAULT_IS_LOADING;

const DEFAULT_RENDER_ERROR = ({
  error
}) => {
  let errStr = (0, _graphql.stringifyGraphqlError)(error);
  const errStrLowercase = errStr.toLowerCase();

  if (errStrLowercase.includes('failed to fetch')) {
    errStr = 'We were unable to connect to our backend server. Is your internet connection working?';
  }

  return _react.default.createElement(_ErrorBox.default, {
    error: errStr
  });
};

exports.DEFAULT_RENDER_ERROR = DEFAULT_RENDER_ERROR;

const DEFAULT_RENDER_LOADING = () => _react.default.createElement(_LoadingIcon.default, null);

exports.DEFAULT_RENDER_LOADING = DEFAULT_RENDER_LOADING;

const Query = props => {
  const {
    children,
    isLoading = DEFAULT_IS_LOADING,
    renderError = DEFAULT_RENDER_ERROR,
    renderLoading = DEFAULT_RENDER_LOADING,
    skipErrorHandler = false,
    skipLoadingHandler = false
  } = props,
        otherProps = _objectWithoutProperties(props, ["children", "isLoading", "renderError", "renderLoading", "skipErrorHandler", "skipLoadingHandler"]);

  return _react.default.createElement(_reactApollo.Query, otherProps, result => {
    if (!skipLoadingHandler && isLoading(result)) {
      return renderLoading(result);
    }

    const {
      error
    } = result;

    if (!skipErrorHandler && error) {
      return renderError(result);
    }

    return children(result);
  });
};

var _default = Query;
exports.default = _default;