"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useInput = void 0;

var _react = require("react");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const inputIsEmpty = val => val === null || val === undefined || val === '' || Array.isArray(val) && !val.length;

const inputValueReducer = (state, {
  id,
  value
}) => {
  if (state[id] !== value) {
    return _objectSpread({}, state, {
      [id]: value
    });
  } else {
    return state;
  }
};

const inputValidationReducer = (state, {
  id,
  valid,
  error
}) => {
  if (JSON.stringify(state[id]) !== JSON.stringify({
    valid,
    error
  })) {
    return _objectSpread({}, state, {
      [id]: {
        valid,
        error
      }
    });
  } else {
    return state;
  }
};

const createInitialInputValueState = inputs => inputs.reduce((m, {
  id,
  config: {
    initialValue
  }
}) => {
  m[id] = initialValue || '';
  return m;
}, {});

const createInitialInputValidationState = inputs => inputs.reduce((m, {
  id
}) => {
  m[id] = {
    valid: false
  };
  return m;
}, {});

const useInput = ({
  inputs,
  validate
}) => {
  const [inputValue, updateInputValue] = (0, _react.useReducer)(inputValueReducer, inputs, createInitialInputValueState);
  const [inputValidation, updateInputValidation] = (0, _react.useReducer)(inputValidationReducer, inputs, createInitialInputValidationState);
  const onInputChange = (0, _react.useMemo)(() => inputs.reduce((m, {
    id
  }) => {
    m[id] = value => {
      updateInputValue({
        id,
        value
      });
    };

    return m;
  }, {}), [updateInputValue, inputs]);
  const allInputsAreValid = (0, _react.useMemo)(() => Object.values(inputValidation).reduce((m, {
    valid
  }) => m && valid, true), [inputValidation]);
  (0, _react.useEffect)(() => {
    (async () => {
      let errorDetails = {};

      try {
        await validate(inputValue);
      } catch (err) {
        errorDetails = err.details || {};
      }

      Object.keys(inputValue).forEach(inputId => {
        if (inputIsEmpty(inputValue[inputId])) {
          updateInputValidation({
            id: inputId,
            valid: false,
            error: null
          });
        } else if (errorDetails[inputId]) {
          updateInputValidation({
            id: inputId,
            valid: false,
            error: errorDetails[inputId]
          });
        } else {
          updateInputValidation({
            id: inputId,
            valid: true
          });
        }
      });
    })();
  }, [validate, inputValue, updateInputValidation]);
  return {
    inputValue,
    updateInputValue,
    inputValidation,
    updateInputValidation,
    allInputsAreValid,
    onInputChange
  };
};

exports.useInput = useInput;